==> benchling-api-client-0.10.6a0.tar.gz: benchling-api-client-0.10.6a0/benchling_api_client/api/custom_entities/archive_custom_entities.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.bad_request_error import BadRequestError
from ...models.custom_entities_archival_change import CustomEntitiesArchivalChange
from ...models.custom_entities_archive import CustomEntitiesArchive
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Dict[str, Any]:
    url = "{}/custom-entities:archive".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    if response.status_code == 200:
        response_200 = CustomEntitiesArchivalChange.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = BadRequestError.from_dict(response.json())

        return response_400
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Response[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Optional[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    """ Archive custom entities """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Response[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Optional[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    """ Archive custom entities """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> benchling-api-client-2.0.13.tar.gz: benchling-api-client-2.0.13/benchling_api_client/api/custom_entities/archive_custom_entities.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.bad_request_error import BadRequestError
from ...models.custom_entities_archival_change import CustomEntitiesArchivalChange
from ...models.custom_entities_archive import CustomEntitiesArchive
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Dict[str, Any]:
    url = "{}/custom-entities:archive".format(client.base_url)

    headers: Dict[str, Any] = client.httpx_client.headers
    headers.update(client.get_headers())

    cookies: Dict[str, Any] = client.httpx_client.cookies
    cookies.update(client.get_cookies())

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    if response.status_code == 200:
        response_200 = CustomEntitiesArchivalChange.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = BadRequestError.from_dict(response.json())

        return response_400
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Response[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = client.httpx_client.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Optional[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    """ Archive custom entities """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Response[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: CustomEntitiesArchive,
) -> Optional[Union[CustomEntitiesArchivalChange, BadRequestError]]:
    """ Archive custom entities """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
